﻿using System;
using System.ComponentModel;
using System.Windows;
using System.Windows.Media;
using Ventuz.Remoting4;
using Ventuz.Remoting4.Templates;


namespace Remoting4_Demo_4
{
    /// <summary>
    /// Interaction logic for ScreenshotDisplay.xaml
    /// </summary>
    public partial class ScreenshotDisplay : Window, INotifyPropertyChanged
    {
        Cluster cluster = null;
        IID pipe = IID.Invalid;
        
        ImageSource snapImg = null;
        public ImageSource SnapshotImage
        {
            get { return this.snapImg; }
            set
            {
                this.snapImg = value;
                OnPropertyChanged();
            }
        }

        public ScreenshotDisplay()
        {
            InitializeComponent();
        }

        public void SetCluster(Cluster cluster, IID pipe)
        {
            this.cluster = cluster;
            this.pipe = pipe;
        }

        private async void Snapshot_Click(object sender, RoutedEventArgs e)
        {
            if ( this.cluster != null )
            {
                ImageFormat imgF = (ImageFormat)this.cbFormat.SelectedIndex;
                int? w = null;
                int? h = null;
                int? rX = null;
                int? rY = null;
                int? rW = null;
                int? rH = null;

                try
                {
                    // get parameters for snapshot method from dialog
                    if ( !string.IsNullOrWhiteSpace(this.tbWidth.Text) )    w = int.Parse(this.tbWidth.Text);
                    if ( !string.IsNullOrWhiteSpace(this.tbHeight.Text) )   h = int.Parse(this.tbHeight.Text);
                    if ( !string.IsNullOrWhiteSpace(this.tbX.Text) )        rX = int.Parse(this.tbX.Text);
                    if ( !string.IsNullOrWhiteSpace(this.tbY.Text) )        rY = int.Parse(this.tbY.Text);
                    if ( !string.IsNullOrWhiteSpace(this.tbSizeX.Text) )    rW = int.Parse(this.tbSizeX.Text);
                    if ( !string.IsNullOrWhiteSpace(this.tbSizeY.Text) )    rH = int.Parse(this.tbSizeY.Text);
                }
                catch ( Exception ex )
                {
                    MessageBox.Show(this, string.Format("Invalid parameters for snapshot: {0}", ex.Message), "Error");
                }

                try
                {
                    byte[] sn = await this.cluster.Snapshot(this.pipe, imgF, w, h, rX, rY, rW, rH, Filter.None, this.cbAlpha.IsChecked.Value, null);

                    // convert byte array to BitmapSource
                    this.SnapshotImage = Ventuz.Remoting4.Templates.Template.BitmapSourceFromByteArray(sn);
                }
                catch ( Exception ex )
                {
                    MessageBox.Show(this, string.Format("Snapshot failed: {0}", ex.Message), "Error");
                }
            }
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        protected void OnPropertyChanged([System.Runtime.CompilerServices.CallerMemberName]string name = null)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if ( handler != null && !string.IsNullOrWhiteSpace(name) )
                handler(this, new PropertyChangedEventArgs(name));
        }


        #endregion
    }
}
